=begin
#Golden Service API

#An API that conforms to the standards and best practices that should be adhered to in all Mastercard owned APIs. Can be used to create subscriptions to reports that are generated twice daily (6am & 6pm) that deliver e-commerce spending across multiple sectors and locations. <br/> --- * **All requests must be signed using oauth 1.0a. Please refer to: https://developer.mastercard.com/platform/documentation/using-oauth-1a-to-access-mastercard-apis/** --- * **The user must provide their card details when creating a subscription. These details must be encrypted before entering transit. Please refer to [Mastercard security](https://stage.developer.mastercard.com/platform/documentation/securing-sensitive-data-using-payload-encryption/)** --- 

The version of the OpenAPI document: 1.1.0
Contact: developers@mastercard.com
Generated by: https://openapi-generator.tech
OpenAPI Generator version: 4.0.1-SNAPSHOT

=end

require 'uri'

module OpenapiClient
  class ReportsApi
    attr_accessor :api_client

    def initialize(api_client = ApiClient.default)
      @api_client = api_client
    end
    # Retrieves e-commerce spending for a particular location, sector and date range or single date
    # @param date [Date] The date for the requested data
    # @param location [String] The location for which you wish to receive the top-sectors report.
    # @param spending_type [String] Used to distinguish between gross spending (GS) &amp; average transaction value (ATV)
    # @param [Hash] opts the optional parameters
    # @option opts [Integer] :sector The sector for which you wish to receive reports. Sector ids can be retrieved from sectors call
    # @return [SpendingReport]
    def get_spending(date, location, spending_type, opts = {})
      data, _status_code, _headers = get_spending_with_http_info(date, location, spending_type, opts)
      data
    end

    # Retrieves e-commerce spending for a particular location, sector and date range or single date
    # @param date [Date] The date for the requested data
    # @param location [String] The location for which you wish to receive the top-sectors report.
    # @param spending_type [String] Used to distinguish between gross spending (GS) &amp; average transaction value (ATV)
    # @param [Hash] opts the optional parameters
    # @option opts [Integer] :sector The sector for which you wish to receive reports. Sector ids can be retrieved from sectors call
    # @return [Array<(SpendingReport, Integer, Hash)>] SpendingReport data, response status code and response headers
    def get_spending_with_http_info(date, location, spending_type, opts = {})
      if @api_client.config.debugging
        @api_client.config.logger.debug 'Calling API: ReportsApi.get_spending ...'
      end
      # verify the required parameter 'date' is set
      if @api_client.config.client_side_validation && date.nil?
        fail ArgumentError, "Missing the required parameter 'date' when calling ReportsApi.get_spending"
      end
      # verify the required parameter 'location' is set
      if @api_client.config.client_side_validation && location.nil?
        fail ArgumentError, "Missing the required parameter 'location' when calling ReportsApi.get_spending"
      end
      # verify the required parameter 'spending_type' is set
      if @api_client.config.client_side_validation && spending_type.nil?
        fail ArgumentError, "Missing the required parameter 'spending_type' when calling ReportsApi.get_spending"
      end
      # resource path
      local_var_path = '/spending-reports'

      # query parameters
      query_params = opts[:query_params] || {}
      query_params[:'date'] = date
      query_params[:'location'] = location
      query_params[:'spending_type'] = spending_type
      query_params[:'sector'] = opts[:'sector'] if !opts[:'sector'].nil?

      # header parameters
      header_params = opts[:header_params] || {}
      # HTTP header 'Accept' (if needed)
      header_params['Accept'] = @api_client.select_header_accept(['application/json'])

      # form parameters
      form_params = opts[:form_params] || {}

      # http body (model)
      post_body = opts[:body] 

      # return_type
      return_type = opts[:return_type] || 'SpendingReport' 

      # auth_names
      auth_names = opts[:auth_names] || []

      new_options = opts.merge(
        :header_params => header_params,
        :query_params => query_params,
        :form_params => form_params,
        :body => post_body,
        :auth_names => auth_names,
        :return_type => return_type
      )

      data, status_code, headers = @api_client.call_api(:GET, local_var_path, new_options)
      if @api_client.config.debugging
        @api_client.config.logger.debug "API called: ReportsApi#get_spending\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
      end
      return data, status_code, headers
    end

    # Retrieves the top grossing locations for the specified date/sector/spending type
    # @param date [Date] The date for the requested data
    # @param spending_type [String] Used to distinguish between gross spending (GS) &amp; average transaction value (ATV)
    # @param [Hash] opts the optional parameters
    # @option opts [Integer] :sector The sector for which you wish to receive reports. Sector ids can be retrieved from sectors call
    # @option opts [Integer] :limit Can be used to limit the amount of results returned from a query (Pagination)
    # @option opts [Integer] :offset The number of items to offset the start of the list from (Pagination)
    # @return [TopLocationsReport]
    def get_top_locations(date, spending_type, opts = {})
      data, _status_code, _headers = get_top_locations_with_http_info(date, spending_type, opts)
      data
    end

    # Retrieves the top grossing locations for the specified date/sector/spending type
    # @param date [Date] The date for the requested data
    # @param spending_type [String] Used to distinguish between gross spending (GS) &amp; average transaction value (ATV)
    # @param [Hash] opts the optional parameters
    # @option opts [Integer] :sector The sector for which you wish to receive reports. Sector ids can be retrieved from sectors call
    # @option opts [Integer] :limit Can be used to limit the amount of results returned from a query (Pagination)
    # @option opts [Integer] :offset The number of items to offset the start of the list from (Pagination)
    # @return [Array<(TopLocationsReport, Integer, Hash)>] TopLocationsReport data, response status code and response headers
    def get_top_locations_with_http_info(date, spending_type, opts = {})
      if @api_client.config.debugging
        @api_client.config.logger.debug 'Calling API: ReportsApi.get_top_locations ...'
      end
      # verify the required parameter 'date' is set
      if @api_client.config.client_side_validation && date.nil?
        fail ArgumentError, "Missing the required parameter 'date' when calling ReportsApi.get_top_locations"
      end
      # verify the required parameter 'spending_type' is set
      if @api_client.config.client_side_validation && spending_type.nil?
        fail ArgumentError, "Missing the required parameter 'spending_type' when calling ReportsApi.get_top_locations"
      end
      # resource path
      local_var_path = '/top-locations'

      # query parameters
      query_params = opts[:query_params] || {}
      query_params[:'date'] = date
      query_params[:'spending_type'] = spending_type
      query_params[:'sector'] = opts[:'sector'] if !opts[:'sector'].nil?
      query_params[:'limit'] = opts[:'limit'] if !opts[:'limit'].nil?
      query_params[:'offset'] = opts[:'offset'] if !opts[:'offset'].nil?

      # header parameters
      header_params = opts[:header_params] || {}
      # HTTP header 'Accept' (if needed)
      header_params['Accept'] = @api_client.select_header_accept(['application/json'])

      # form parameters
      form_params = opts[:form_params] || {}

      # http body (model)
      post_body = opts[:body] 

      # return_type
      return_type = opts[:return_type] || 'TopLocationsReport' 

      # auth_names
      auth_names = opts[:auth_names] || []

      new_options = opts.merge(
        :header_params => header_params,
        :query_params => query_params,
        :form_params => form_params,
        :body => post_body,
        :auth_names => auth_names,
        :return_type => return_type
      )

      data, status_code, headers = @api_client.call_api(:GET, local_var_path, new_options)
      if @api_client.config.debugging
        @api_client.config.logger.debug "API called: ReportsApi#get_top_locations\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
      end
      return data, status_code, headers
    end

    # Retrieves the top grossing sectors for the specified date & location
    # @param date [Date] The date for the requested data
    # @param location [String] The location for which you wish to receive the top-sectors report.
    # @param spending_type [String] Used to distinguish between gross spending (GS) &amp; average transaction value (ATV)
    # @param [Hash] opts the optional parameters
    # @return [Array<Array>]
    def get_top_sectors(date, location, spending_type, opts = {})
      data, _status_code, _headers = get_top_sectors_with_http_info(date, location, spending_type, opts)
      data
    end

    # Retrieves the top grossing sectors for the specified date &amp; location
    # @param date [Date] The date for the requested data
    # @param location [String] The location for which you wish to receive the top-sectors report.
    # @param spending_type [String] Used to distinguish between gross spending (GS) &amp; average transaction value (ATV)
    # @param [Hash] opts the optional parameters
    # @return [Array<(Array<Array>, Integer, Hash)>] Array<Array> data, response status code and response headers
    def get_top_sectors_with_http_info(date, location, spending_type, opts = {})
      if @api_client.config.debugging
        @api_client.config.logger.debug 'Calling API: ReportsApi.get_top_sectors ...'
      end
      # verify the required parameter 'date' is set
      if @api_client.config.client_side_validation && date.nil?
        fail ArgumentError, "Missing the required parameter 'date' when calling ReportsApi.get_top_sectors"
      end
      # verify the required parameter 'location' is set
      if @api_client.config.client_side_validation && location.nil?
        fail ArgumentError, "Missing the required parameter 'location' when calling ReportsApi.get_top_sectors"
      end
      # verify the required parameter 'spending_type' is set
      if @api_client.config.client_side_validation && spending_type.nil?
        fail ArgumentError, "Missing the required parameter 'spending_type' when calling ReportsApi.get_top_sectors"
      end
      # resource path
      local_var_path = '/top-sectors'

      # query parameters
      query_params = opts[:query_params] || {}
      query_params[:'date'] = date
      query_params[:'location'] = location
      query_params[:'spending_type'] = spending_type

      # header parameters
      header_params = opts[:header_params] || {}
      # HTTP header 'Accept' (if needed)
      header_params['Accept'] = @api_client.select_header_accept(['application/json'])

      # form parameters
      form_params = opts[:form_params] || {}

      # http body (model)
      post_body = opts[:body] 

      # return_type
      return_type = opts[:return_type] || 'Array<Array>' 

      # auth_names
      auth_names = opts[:auth_names] || []

      new_options = opts.merge(
        :header_params => header_params,
        :query_params => query_params,
        :form_params => form_params,
        :body => post_body,
        :auth_names => auth_names,
        :return_type => return_type
      )

      data, status_code, headers = @api_client.call_api(:GET, local_var_path, new_options)
      if @api_client.config.debugging
        @api_client.config.logger.debug "API called: ReportsApi#get_top_sectors\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
      end
      return data, status_code, headers
    end
  end
end
