=begin
#Golden Service API

#An API that conforms to the standards and best practices that should be adhered to in all Mastercard owned APIs. Can be used to create subscriptions to reports that are generated twice daily (6am & 6pm) that deliver e-commerce spending across multiple sectors and locations. <br/> --- * **All requests must be signed using oauth 1.0a. Please refer to: https://developer.mastercard.com/platform/documentation/using-oauth-1a-to-access-mastercard-apis/** --- * **The user must provide their card details when creating a subscription. These details must be encrypted before entering transit. Please refer to [Mastercard security](https://stage.developer.mastercard.com/platform/documentation/securing-sensitive-data-using-payload-encryption/)** --- 

The version of the OpenAPI document: 1.1.0
Contact: developers@mastercard.com
Generated by: https://openapi-generator.tech
OpenAPI Generator version: 4.0.1-SNAPSHOT

=end

require 'uri'

module OpenapiClient
  class SubscribeApi
    attr_accessor :api_client

    def initialize(api_client = ApiClient.default)
      @api_client = api_client
    end
    # Gets a specific subscription using a subscription Id passed as in the path
    # @param subscription_id [String] Unique identifier of a particular subscription (UUID Version 4)
    # @param [Hash] opts the optional parameters
    # @return [SubscriptionResponse]
    def get_subscription(subscription_id, opts = {})
      data, _status_code, _headers = get_subscription_with_http_info(subscription_id, opts)
      data
    end

    # Gets a specific subscription using a subscription Id passed as in the path
    # @param subscription_id [String] Unique identifier of a particular subscription (UUID Version 4)
    # @param [Hash] opts the optional parameters
    # @return [Array<(SubscriptionResponse, Integer, Hash)>] SubscriptionResponse data, response status code and response headers
    def get_subscription_with_http_info(subscription_id, opts = {})
      if @api_client.config.debugging
        @api_client.config.logger.debug 'Calling API: SubscribeApi.get_subscription ...'
      end
      # verify the required parameter 'subscription_id' is set
      if @api_client.config.client_side_validation && subscription_id.nil?
        fail ArgumentError, "Missing the required parameter 'subscription_id' when calling SubscribeApi.get_subscription"
      end
      # resource path
      local_var_path = '/subscriptions/{subscription_id}'.sub('{' + 'subscription_id' + '}', subscription_id.to_s)

      # query parameters
      query_params = opts[:query_params] || {}

      # header parameters
      header_params = opts[:header_params] || {}
      # HTTP header 'Accept' (if needed)
      header_params['Accept'] = @api_client.select_header_accept(['application/json'])

      # form parameters
      form_params = opts[:form_params] || {}

      # http body (model)
      post_body = opts[:body] 

      # return_type
      return_type = opts[:return_type] || 'SubscriptionResponse' 

      # auth_names
      auth_names = opts[:auth_names] || []

      new_options = opts.merge(
        :header_params => header_params,
        :query_params => query_params,
        :form_params => form_params,
        :body => post_body,
        :auth_names => auth_names,
        :return_type => return_type
      )

      data, status_code, headers = @api_client.call_api(:GET, local_var_path, new_options)
      if @api_client.config.debugging
        @api_client.config.logger.debug "API called: SubscribeApi#get_subscription\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
      end
      return data, status_code, headers
    end

    # gets all active subscriptions for a particular user. Returned list size can be limited using the limit parameter
    # @param [Hash] opts the optional parameters
    # @option opts [Integer] :limit Can be used to limit the amount of results returned from a query (Pagination)
    # @option opts [Integer] :offset The number of items to offset the start of the list from (Pagination)
    # @return [Array<ActiveSubscription>]
    def list_subscriptions(opts = {})
      data, _status_code, _headers = list_subscriptions_with_http_info(opts)
      data
    end

    # gets all active subscriptions for a particular user. Returned list size can be limited using the limit parameter
    # @param [Hash] opts the optional parameters
    # @option opts [Integer] :limit Can be used to limit the amount of results returned from a query (Pagination)
    # @option opts [Integer] :offset The number of items to offset the start of the list from (Pagination)
    # @return [Array<(Array<ActiveSubscription>, Integer, Hash)>] Array<ActiveSubscription> data, response status code and response headers
    def list_subscriptions_with_http_info(opts = {})
      if @api_client.config.debugging
        @api_client.config.logger.debug 'Calling API: SubscribeApi.list_subscriptions ...'
      end
      # resource path
      local_var_path = '/subscriptions'

      # query parameters
      query_params = opts[:query_params] || {}
      query_params[:'limit'] = opts[:'limit'] if !opts[:'limit'].nil?
      query_params[:'offset'] = opts[:'offset'] if !opts[:'offset'].nil?

      # header parameters
      header_params = opts[:header_params] || {}
      # HTTP header 'Accept' (if needed)
      header_params['Accept'] = @api_client.select_header_accept(['application/json'])

      # form parameters
      form_params = opts[:form_params] || {}

      # http body (model)
      post_body = opts[:body] 

      # return_type
      return_type = opts[:return_type] || 'Array<ActiveSubscription>' 

      # auth_names
      auth_names = opts[:auth_names] || []

      new_options = opts.merge(
        :header_params => header_params,
        :query_params => query_params,
        :form_params => form_params,
        :body => post_body,
        :auth_names => auth_names,
        :return_type => return_type
      )

      data, status_code, headers = @api_client.call_api(:GET, local_var_path, new_options)
      if @api_client.config.debugging
        @api_client.config.logger.debug "API called: SubscribeApi#list_subscriptions\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
      end
      return data, status_code, headers
    end

    # Allows the user to subscribe to a particular location and receive updates on e-commerce spending in their chosen area. The user can pay for the subscription on a daily basis. The user is charged for every report they receive until their subscription is cancelled
    # @param request_body [Hash<String, SubscriptionObject>] Request body required to create a particular subscription
    # @param [Hash] opts the optional parameters
    # @return [Array<SubscriptionResponse>]
    def subscribe(request_body, opts = {})
      data, _status_code, _headers = subscribe_with_http_info(request_body, opts)
      data
    end

    # Allows the user to subscribe to a particular location and receive updates on e-commerce spending in their chosen area. The user can pay for the subscription on a daily basis. The user is charged for every report they receive until their subscription is cancelled
    # @param request_body [Hash<String, SubscriptionObject>] Request body required to create a particular subscription
    # @param [Hash] opts the optional parameters
    # @return [Array<(Array<SubscriptionResponse>, Integer, Hash)>] Array<SubscriptionResponse> data, response status code and response headers
    def subscribe_with_http_info(request_body, opts = {})
      if @api_client.config.debugging
        @api_client.config.logger.debug 'Calling API: SubscribeApi.subscribe ...'
      end
      # verify the required parameter 'request_body' is set
      if @api_client.config.client_side_validation && request_body.nil?
        fail ArgumentError, "Missing the required parameter 'request_body' when calling SubscribeApi.subscribe"
      end
      # resource path
      local_var_path = '/subscriptions'

      # query parameters
      query_params = opts[:query_params] || {}

      # header parameters
      header_params = opts[:header_params] || {}
      # HTTP header 'Accept' (if needed)
      header_params['Accept'] = @api_client.select_header_accept(['application/json'])
      # HTTP header 'Content-Type'
      header_params['Content-Type'] = @api_client.select_header_content_type(['application/json'])

      # form parameters
      form_params = opts[:form_params] || {}

      # http body (model)
      post_body = opts[:body] || @api_client.object_to_http_body(request_body) 

      # return_type
      return_type = opts[:return_type] || 'Array<SubscriptionResponse>' 

      # auth_names
      auth_names = opts[:auth_names] || []

      new_options = opts.merge(
        :header_params => header_params,
        :query_params => query_params,
        :form_params => form_params,
        :body => post_body,
        :auth_names => auth_names,
        :return_type => return_type
      )

      data, status_code, headers = @api_client.call_api(:POST, local_var_path, new_options)
      if @api_client.config.debugging
        @api_client.config.logger.debug "API called: SubscribeApi#subscribe\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
      end
      return data, status_code, headers
    end

    # Un-subscribes from a specified subcription
    # @param subscription_id [String] Unique identifier of a particular subscription (Version 4 UUID)
    # @param [Hash] opts the optional parameters
    # @return [UnsubscribedResponse]
    def unsubscribe(subscription_id, opts = {})
      data, _status_code, _headers = unsubscribe_with_http_info(subscription_id, opts)
      data
    end

    # Un-subscribes from a specified subcription
    # @param subscription_id [String] Unique identifier of a particular subscription (Version 4 UUID)
    # @param [Hash] opts the optional parameters
    # @return [Array<(UnsubscribedResponse, Integer, Hash)>] UnsubscribedResponse data, response status code and response headers
    def unsubscribe_with_http_info(subscription_id, opts = {})
      if @api_client.config.debugging
        @api_client.config.logger.debug 'Calling API: SubscribeApi.unsubscribe ...'
      end
      # verify the required parameter 'subscription_id' is set
      if @api_client.config.client_side_validation && subscription_id.nil?
        fail ArgumentError, "Missing the required parameter 'subscription_id' when calling SubscribeApi.unsubscribe"
      end
      # resource path
      local_var_path = '/subscriptions'

      # query parameters
      query_params = opts[:query_params] || {}
      query_params[:'subscription_id'] = subscription_id

      # header parameters
      header_params = opts[:header_params] || {}
      # HTTP header 'Accept' (if needed)
      header_params['Accept'] = @api_client.select_header_accept(['application/json'])

      # form parameters
      form_params = opts[:form_params] || {}

      # http body (model)
      post_body = opts[:body] 

      # return_type
      return_type = opts[:return_type] || 'UnsubscribedResponse' 

      # auth_names
      auth_names = opts[:auth_names] || []

      new_options = opts.merge(
        :header_params => header_params,
        :query_params => query_params,
        :form_params => form_params,
        :body => post_body,
        :auth_names => auth_names,
        :return_type => return_type
      )

      data, status_code, headers = @api_client.call_api(:DELETE, local_var_path, new_options)
      if @api_client.config.debugging
        @api_client.config.logger.debug "API called: SubscribeApi#unsubscribe\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
      end
      return data, status_code, headers
    end

    # Updates an active subscription
    # @param subscription_id [String] Unique identifier of a particular subscription (UUID Version 4)
    # @param subscription_object [SubscriptionObject] Request body required to update a particular subscription
    # @param [Hash] opts the optional parameters
    # @return [SubscriptionResponse]
    def update_subscription(subscription_id, subscription_object, opts = {})
      data, _status_code, _headers = update_subscription_with_http_info(subscription_id, subscription_object, opts)
      data
    end

    # Updates an active subscription
    # @param subscription_id [String] Unique identifier of a particular subscription (UUID Version 4)
    # @param subscription_object [SubscriptionObject] Request body required to update a particular subscription
    # @param [Hash] opts the optional parameters
    # @return [Array<(SubscriptionResponse, Integer, Hash)>] SubscriptionResponse data, response status code and response headers
    def update_subscription_with_http_info(subscription_id, subscription_object, opts = {})
      if @api_client.config.debugging
        @api_client.config.logger.debug 'Calling API: SubscribeApi.update_subscription ...'
      end
      # verify the required parameter 'subscription_id' is set
      if @api_client.config.client_side_validation && subscription_id.nil?
        fail ArgumentError, "Missing the required parameter 'subscription_id' when calling SubscribeApi.update_subscription"
      end
      # verify the required parameter 'subscription_object' is set
      if @api_client.config.client_side_validation && subscription_object.nil?
        fail ArgumentError, "Missing the required parameter 'subscription_object' when calling SubscribeApi.update_subscription"
      end
      # resource path
      local_var_path = '/subscriptions'

      # query parameters
      query_params = opts[:query_params] || {}
      query_params[:'subscription_id'] = subscription_id

      # header parameters
      header_params = opts[:header_params] || {}
      # HTTP header 'Accept' (if needed)
      header_params['Accept'] = @api_client.select_header_accept(['application/json'])
      # HTTP header 'Content-Type'
      header_params['Content-Type'] = @api_client.select_header_content_type(['application/json'])

      # form parameters
      form_params = opts[:form_params] || {}

      # http body (model)
      post_body = opts[:body] || @api_client.object_to_http_body(subscription_object) 

      # return_type
      return_type = opts[:return_type] || 'SubscriptionResponse' 

      # auth_names
      auth_names = opts[:auth_names] || []

      new_options = opts.merge(
        :header_params => header_params,
        :query_params => query_params,
        :form_params => form_params,
        :body => post_body,
        :auth_names => auth_names,
        :return_type => return_type
      )

      data, status_code, headers = @api_client.call_api(:PUT, local_var_path, new_options)
      if @api_client.config.debugging
        @api_client.config.logger.debug "API called: SubscribeApi#update_subscription\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
      end
      return data, status_code, headers
    end
  end
end
